#### vChatGPT
You can talk to and listen to ChatGPT.

#### Demo screenshot
 Input: Your voice through a microphone  
Output: Speech reaction of ChatGPT from speakers as well as text  
![alt text](https://github.com/ywatanabe1989/vChatGPT/blob/main/docs/vChatGPT_demo.png?raw=true)

#### Installation
``` bash
$ pip install vChatGPT
```

#### How to run vChatGPT
``` bash
$ export OPENAI_API_KEY="52-DIGIT-YOUR_API_KEY" # Available on https://platform.openai.com/account/api-keys
$ python -m vChatGPT
```
